Includes commands for bootstrapping and permutation tests, a command for created grouped bar plots, and a demo of the quantile-normal plot for data drawn from different distributions.
Maintainer: Adam Loy aloy@carleton.edu (ORCID)
Authors:
Adam Loy aloy@carleton.edu (ORCID)
Laura Chihara flchihara@carleton.edu
Useful links: