- x
a numeric, logical, factor, or character vector. Logical, factor,
and character vectors with exactly two unique values are converted to 0/1,
and mean is used to compute the proportion.
- ...
further arguments to be passed to or from methods.
- group
an optional grouping variable (vector), usually a factor
variable. If it is a binary numeric variable, it will be coerced to a
factor.
- statistic
function that computes the statistic of interest. Default
is the mean.
- success
a character string naming the level of x to code as
1 when x is a logical, factor, or character variable. Defaults to
NULL, which uses the second factor level (alphabetically) or
TRUE for logical vectors.
- conf.level
confidence level for the bootstrap percentile interval.
Default is 95%.
- B
number of times to resample (positive integer greater than 2).
- plot.hist
logical value. If TRUE, plot the histogram of the
bootstrap distribution.
- plot.qq
Logical value. If TRUE, create a normal
quantile-quantile plot of the bootstrap distribution.
- x.name
Label for variable name
- xlab
an optional character string for the x-axis label
- ylab
an optional character string for the y-axis label
- title
an optional character string giving the plot title
- seed
optional argument to set.seed
- formula
a formula y ~ g where y is a numeric vector and
g a factor variable with two levels. If g is a binary numeric
vector, it will be coerced to a factor variable. For a single numeric variable,
formula may also be ~ y.
- data
a data frame that contains the variables given in the formula.
- subset
an optional expression indicating what observations to use.