- x
a numeric, logical, factor, or character vector. Logical, factor,
and character vectors with exactly two unique values are converted to 0/1,
and mean is used to compute the proportion.
- ...
further arguments to be passed to or from methods.
- group
a factor variable with two levels. If group is a binary
numeric vector, it will be coerced into a factor variable.
- statistic
the statistic of interest.
- success
a character string naming the level of x to code as
1 when x is a logical, factor, or character variable. Defaults to
NULL, which uses the second factor level (alphabetically) or
TRUE for logical vectors.
- B
the number of resamples (positive integer greater than 2).
- alternative
the alternative hypothesis. Options are
"two.sided", "less" or "greater".
- plot.hist
a logical value. If TRUE, the permutation
distribution of the statistic is plotted.
- plot.qq
a logical value. If TRUE, then a normal
quantile-quantile plot of the resampled test statistic is created.
- xlab
an optional character string for the x-axis label
- ylab
an optional character string for the y-axis label
- title
an optional character string giving the plot title
- seed
optional argument to set.seed
- formula
a formula of the form y ~ group where y is
numeric and group is a factor variable.
- data
a data frame with the variables in the formula.
- subset
an optional expression specifying which observations to keep.